pub enum PathEl {
MoveTo(Point),
LineTo(Point),
QuadTo(Point, Point),
CurveTo(Point, Point, Point),
ClosePath,
}Expand description
The element of a Bézier path.
A valid path has MoveTo at the beginning of each subpath.
Variants
MoveTo(Point)
Move directly to the point without drawing anything, starting a new subpath.
LineTo(Point)
Draw a line from the current location to the point.
QuadTo(Point, Point)
Draw a quadratic Bézier using the current location and the two points.
The first point is the Bézier’s control point, the second is its end point.
CurveTo(Point, Point, Point)
Draw a cubic Bézier using the current location and the three points.
The first two points are the Bézier’s control points, the last point is its end point.
ClosePath
Close off the path.
Implementations