pub struct MinDistance {
pub distance: f64,
pub t1: f64,
pub t2: f64,
}Expand description
The minimum distance between two Bézier curves.
Fields
distance: f64The shortest distance between any two points on the two curves.
t1: f64The position of the nearest point on the first curve, as a parameter.
To resolve this to a Point, use ParamCurve::eval.
t2: f64The position of the nearest point on the second curve, as a parameter.
To resolve this to a Point, use ParamCurve::eval.